==> apache-samza-1.0.0-src.tgz: apache-samza-1.0.0-src/samza-rest/src/main/java/org/apache/samza/rest/proxy/task/TaskResourceConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.samza.rest.proxy.task;

import org.apache.samza.config.Config;
import org.apache.samza.rest.resources.BaseResourceConfig;
import org.apache.samza.rest.resources.TasksResource;


/**
 * Configurations for the {@link TasksResource} endpoint.
 */
public class TaskResourceConfig extends BaseResourceConfig {

  /**
   * Specifies the canonical name of the {@link TaskProxyFactory} class to produce
   * {@link TaskProxy} instances.
   *
   * To use your own proxy, implement the factory and specify the class for this config.
   */
  public static final String CONFIG_TASK_PROXY_FACTORY = "task.proxy.factory.class";

  public TaskResourceConfig(Config config) {
    super(config);
  }

  /**
   * @see TaskResourceConfig#CONFIG_TASK_PROXY_FACTORY
   * @return the canonical name of the {@link TaskProxyFactory} class to produce {@link TaskProxy} instances.
   */
  public String getTaskProxyFactory() {
    return get(CONFIG_TASK_PROXY_FACTORY);
  }
}

==> apache-samza-1.8.0-src.tgz: apache-samza-1.8.0-src/samza-rest/src/main/java/org/apache/samza/rest/proxy/task/TaskResourceConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.samza.rest.proxy.task;

import org.apache.samza.config.Config;
import org.apache.samza.rest.resources.BaseResourceConfig;


/**
 * Configurations for the {@link org.apache.samza.rest.resources.TasksResource} endpoint.
 */
public class TaskResourceConfig extends BaseResourceConfig {

  /**
   * Specifies the canonical name of the {@link TaskProxyFactory} class to produce
   * {@link TaskProxy} instances.
   *
   * To use your own proxy, implement the factory and specify the class for this config.
   */
  public static final String CONFIG_TASK_PROXY_FACTORY = "task.proxy.factory.class";

  public TaskResourceConfig(Config config) {
    super(config);
  }

  /**
   * @see TaskResourceConfig#CONFIG_TASK_PROXY_FACTORY
   * @return the canonical name of the {@link TaskProxyFactory} class to produce {@link TaskProxy} instances.
   */
  public String getTaskProxyFactory() {
    return get(CONFIG_TASK_PROXY_FACTORY);
  }
}
